"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LongSizeCSSPropertyValidator = void 0;

var _LongCSSPropertyValidator = require("./LongCSSPropertyValidator");

class LongSizeCSSPropertyValidator extends _LongCSSPropertyValidator.LongCSSPropertyValidator {
  computeSize(value, unit) {
    // TODO handle em / rem
    switch (unit) {
      case '%':
        return "".concat(value, "%");

      case 'px':
        return value;

      case 'cm':
      case 'in':
      case 'mm':
      case 'pc':
      case 'pt':
        return value * this.config.absoluteLengthUnitsMultiplicators[unit];
    }

    return null;
  }

  normalizeRawInlineCSSValue(value) {
    if (value === '0') {
      return 0;
    }

    if (value === 'auto') {
      return value;
    }

    const match = /(\d+\.?\d*)\s*(cm|mm|in|px|pt|pc|em|ex|ch|rem|vw|vh|vmin|vmax|%)/g.exec(value);

    if (match === null) {
      return null;
    }

    return this.computeSize(Number(match[1]), match[2]);
  }

  normalizeNativeValue(value) {
    return this.normalizeInlineCSSValue(value);
  }

}

exports.LongSizeCSSPropertyValidator = LongSizeCSSPropertyValidator;
//# sourceMappingURL=LongSizeCSSPropertyValidator.js.map